@@ -1,4 +1,6 @@
 """Tailwind template tags."""
+
+
 from django import template
 from django.conf import settings
 
@@ -7,7 +9,7 @@ from django_tailwind_cli.utils import get_config
 register = template.Library()
 
 
-@register.inclusion_tag("tailwind_cli/tags/tailwind_css.html")
+@register.inclusion_tag("tailwind_cli/tailwind_css.html")
 def tailwind_css():
     """Template tag to include the css files into the html templates."""
     config = get_config()
